==> huaweicloudsdkgaussdbforopengauss-3.1.139-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/list_instance_engine_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceEngineDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'engine_instance_details': 'list[InstanceEngineDetail]',
        'total_count': 'int'
    }

    attribute_map = {
        'engine_instance_details': 'engine_instance_details',
        'total_count': 'total_count'
    }

    def __init__(self, engine_instance_details=None, total_count=None):
        """ListInstanceEngineDetailResponse

        The model defined in huaweicloud sdk

        :param engine_instance_details: 引擎版本和相应的实例详情。
        :type engine_instance_details: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        :param total_count: 引擎版本数量。
        :type total_count: int
        """
        
        super(ListInstanceEngineDetailResponse, self).__init__()

        self._engine_instance_details = None
        self._total_count = None
        self.discriminator = None

        if engine_instance_details is not None:
            self.engine_instance_details = engine_instance_details
        if total_count is not None:
            self.total_count = total_count

    @property
    def engine_instance_details(self):
        """Gets the engine_instance_details of this ListInstanceEngineDetailResponse.

        引擎版本和相应的实例详情。

        :return: The engine_instance_details of this ListInstanceEngineDetailResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        """
        return self._engine_instance_details

    @engine_instance_details.setter
    def engine_instance_details(self, engine_instance_details):
        """Sets the engine_instance_details of this ListInstanceEngineDetailResponse.

        引擎版本和相应的实例详情。

        :param engine_instance_details: The engine_instance_details of this ListInstanceEngineDetailResponse.
        :type engine_instance_details: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        """
        self._engine_instance_details = engine_instance_details

    @property
    def total_count(self):
        """Gets the total_count of this ListInstanceEngineDetailResponse.

        引擎版本数量。

        :return: The total_count of this ListInstanceEngineDetailResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListInstanceEngineDetailResponse.

        引擎版本数量。

        :param total_count: The total_count of this ListInstanceEngineDetailResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceEngineDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbforopengauss-3.1.143-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/list_instance_engine_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceEngineDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'engine_instance_details': 'list[InstanceEngineDetail]',
        'total_count': 'int'
    }

    attribute_map = {
        'engine_instance_details': 'engine_instance_details',
        'total_count': 'total_count'
    }

    def __init__(self, engine_instance_details=None, total_count=None):
        r"""ListInstanceEngineDetailResponse

        The model defined in huaweicloud sdk

        :param engine_instance_details: 引擎版本和相应的实例详情。
        :type engine_instance_details: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        :param total_count: 引擎版本数量。
        :type total_count: int
        """
        
        super(ListInstanceEngineDetailResponse, self).__init__()

        self._engine_instance_details = None
        self._total_count = None
        self.discriminator = None

        if engine_instance_details is not None:
            self.engine_instance_details = engine_instance_details
        if total_count is not None:
            self.total_count = total_count

    @property
    def engine_instance_details(self):
        r"""Gets the engine_instance_details of this ListInstanceEngineDetailResponse.

        引擎版本和相应的实例详情。

        :return: The engine_instance_details of this ListInstanceEngineDetailResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        """
        return self._engine_instance_details

    @engine_instance_details.setter
    def engine_instance_details(self, engine_instance_details):
        r"""Sets the engine_instance_details of this ListInstanceEngineDetailResponse.

        引擎版本和相应的实例详情。

        :param engine_instance_details: The engine_instance_details of this ListInstanceEngineDetailResponse.
        :type engine_instance_details: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.InstanceEngineDetail`]
        """
        self._engine_instance_details = engine_instance_details

    @property
    def total_count(self):
        r"""Gets the total_count of this ListInstanceEngineDetailResponse.

        引擎版本数量。

        :return: The total_count of this ListInstanceEngineDetailResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ListInstanceEngineDetailResponse.

        引擎版本数量。

        :param total_count: The total_count of this ListInstanceEngineDetailResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceEngineDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
